export declare abstract class AbstractCounter {
    private _targetValue;
    /**
     * Callback's arguments
     * @private
     */
    private _args;
    /**
     * Callback function
     * @private
     */
    private _onFire;
    /**
     * Current step of counter
     * @private
     * @default 0
     */
    private _step;
    /**
     * @constructor
     * @this {AbstractCounter}
     * @param _targetValue counter target value
     * @param onFire callback function
     * @param initialStep initial counter value
     * @param args callback's arguments
     * @throws Error if initial value greatest then target value
     */
    protected constructor(_targetValue: number, onFire?: Function, initialStep?: number, ...args: any[]);
    /**
     * Increment current value of counter
     */
    increment(): void;
    /**
     * Function of changing counter value
     * @param lastStep Prevous step of counter
     *
     * @returns Number value of new step value
     * @protected
     * @virtual
     */
    protected changeStep(lastStep: number): number;
    /**
     * @protected
     * @virtual
     * @param step Current step value
     * @param targetValue Trigger value
     *
     * @returns Boolean signal of matching
     */
    protected checkMatch(step: number, targetValue: number): boolean;
    /**
     * Callback executing routine
     * @protected
     */
    protected onMatch(): void;
    /**
     * Current value of counter
     */
    get currentStep(): number;
    /**
     * Value of callback triggering
     */
    get targetValue(): number;
    /**
     * Callback arguments getter
     */
    get args(): any[];
    /**
     * Callback arguments setter
     * @param v Arguments
     */
    set args(v: any[]);
    /**
     * Callback getter
     */
    get onFire(): Function | null;
    /**
     * Callback setter
     * @param v Callback
     */
    set onFire(v: Function | null);
}
