"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractCounter = void 0;
class AbstractCounter {
    /**
     * @constructor
     * @this {AbstractCounter}
     * @param _targetValue counter target value
     * @param onFire callback function
     * @param initialStep initial counter value
     * @param args callback's arguments
     * @throws Error if initial value greatest then target value
     */
    constructor(_targetValue, onFire, initialStep = 0, ...args) {
        this._targetValue = _targetValue;
        if (this._targetValue <= initialStep) {
            throw new Error(`Bound should be greater then initial value | initial value: ${initialStep} | bound: ${this._targetValue}`);
        }
        this._onFire = onFire !== null && onFire !== void 0 ? onFire : null;
        this._args = args;
        this._step = initialStep;
    }
    /**
     * Increment current value of counter
     */
    increment() {
        this._step = this.changeStep(this._step);
        if (this.checkMatch(this._step, this._targetValue)) {
            this.onMatch();
        }
    }
    /**
     * Function of changing counter value
     * @param lastStep Prevous step of counter
     *
     * @returns Number value of new step value
     * @protected
     * @virtual
     */
    changeStep(lastStep) {
        lastStep++;
        return lastStep;
    }
    /**
     * @protected
     * @virtual
     * @param step Current step value
     * @param targetValue Trigger value
     *
     * @returns Boolean signal of matching
     */
    checkMatch(step, targetValue) {
        return step == targetValue;
    }
    /**
     * Callback executing routine
     * @protected
     */
    onMatch() {
        if (this._onFire != null) {
            this._onFire(...this._args);
        }
    }
    /**
     * Current value of counter
     */
    get currentStep() {
        return this._step;
    }
    /**
     * Value of callback triggering
     */
    get targetValue() {
        return this._targetValue;
    }
    /**
     * Callback arguments getter
     */
    get args() {
        return this._args;
    }
    /**
     * Callback arguments setter
     * @param v Arguments
     */
    set args(v) {
        this._args = v !== null && v !== void 0 ? v : [];
    }
    /**
     * Callback getter
     */
    get onFire() {
        return this._onFire;
    }
    /**
     * Callback setter
     * @param v Callback
     */
    set onFire(v) {
        this._onFire = v;
    }
}
exports.AbstractCounter = AbstractCounter;
