"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Timer = void 0;
class Timer {
    /**
     * @constructor
     * @this {Timer}
     *
     * @param _func Callback function
     * @param _delay Callback executing delay
     * @param _autokill Flag of automatic deleting timer after callback executing
     * @param args Callback arguments
     */
    constructor(_func, _delay, _autokill = true, ...args) {
        this._func = _func;
        this._delay = _delay;
        this._autokill = _autokill;
        this._id = null;
        this._args = [];
        this._started = false;
        this._args = args;
    }
    /**
     * Creates timeout
     * @returns {Timer} reference to current instance
     */
    start() {
        // @ts-ignore
        this._id = setTimeout(() => {
            this._started = true;
            this._func(...this._args);
            if (this.kill && this.alive && this.autokill) {
                this.kill();
            }
        }, this._delay);
        return this;
    }
    /**
     * Removes timeout
     * @returns {Timer} reference to current instance
     */
    kill() {
        // @ts-ignore
        clearTimeout(this._id);
        this._id = null;
        return this;
    }
    /**
     * @returns {boolean} Marker of interval state
     */
    get alive() {
        return this._id != null;
    }
    get routineStarted() {
        return this._started;
    }
    /**
     * @returns {boolean} Flag of automatic deleting timer after callback executing
     */
    get autokill() {
        return this._autokill;
    }
    /**
     * @returns {number} Callback executing delay
     */
    get delay() {
        return this._delay;
    }
}
exports.Timer = Timer;
