"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UUIDGenerator = void 0;
const random_1 = require("./random");
const crypto_1 = __importDefault(require("crypto"));
class UUIDGenerator {
    constructor(first, second) {
        this.random = new random_1.Random();
        this.staticData = '';
        this.version = '';
        this.variant = '';
        if (first != null) {
            this.readFirstParam(first);
        }
        if (second) {
            this.staticData = this.convertStatic(second);
        }
        this.version = this.version || '4';
        this.staticData = this.staticData || this.defaultStatic();
        this.variant = this.getVariant();
    }
    defaultStatic() {
        const data = Date.now().toString(16) + this.random.next().toString(16);
        return this.convertStatic(data);
    }
    readFirstParam(first) {
        if (typeof first == 'number') {
            this.version = this.toString(first);
        }
        else if (typeof first == 'string') {
            this.staticData = this.convertStatic(first);
        }
    }
    getVariant() {
        return this.toString(this.random.next(16));
    }
    convertStatic(userStatic) {
        return this.getHashCode(userStatic);
    }
    generateStatic(length) {
        let staticData = '';
        for (let i = 0; i < length; i++) {
            const rand = this.random.next(16);
            staticData += this.toString(rand);
        }
        return staticData;
    }
    /**
     * returns uuid
     */
    generate() {
        const date = this.getDateHEX().padStart(12, '0');
        const version = this.version.toString();
        const variant = this.variant.toString();
        const staticData = this.staticData;
        const random = this.generateStatic(6);
        return `${date.slice(0, 8)}-${date.slice(8, 12)}-${version}${random.slice(0, 3)}-${variant}${random.slice(3, 6)}-${staticData}`;
    }
    getDateHEX() {
        const date = new Date().getTime();
        return this.toString(date).replace('.', '');
    }
    getHashCode(str) {
        const hash = crypto_1.default.createHash('sha1');
        hash.update(str);
        return hash.digest('hex').slice(0, 12);
    }
    toString(number) {
        return number.toString(16);
    }
}
exports.UUIDGenerator = UUIDGenerator;
